@@ -1463,6 +1463,7 @@ def compute_alpha_signal_dynamical_ls_neutral(lo_df=None, core_tokens=['BTC', 'E
         compo['SCASH'] = 1.-compo['long_expo']+ compo['short_expo']
         return compo
 
+    aggregated_signals_df = aggregated_signals_df.drop_duplicates()
     comp_compo = lambda x : compute_ls_expo(x, universe=ssjs, moderating_factor=moderating_factor)
     aggregated_signals_df['compo'] = aggregated_signals_df.apply(comp_compo, axis = 1)
 
@@ -1476,7 +1477,7 @@ def compute_alpha_signal_dynamical_ls_neutral(lo_df=None, core_tokens=['BTC', 'E
     merged_df = merged_df.iloc[1:]
     merged_df.replace([np.inf, -np.inf], np.nan, inplace=True)
     merged_df = merged_df.fillna(0.)
-
+    merged_df = merged_df.drop_duplicates()
     print('computing exposition')
     def compute_strat_ret(row_df, universe = None, stable_annulalized_apy=0.03):
         aggregated_return = 0.
